@@ -6,7 +6,7 @@
 #' @param seed pseudo-random number generator seed
 #' @return A vector containing the generated sample
 sample_within_range <- function(rg, sample_size = NULL, seed = NULL) {
-    check_condition(class(rg) != "range" | length(rg) != 2,
+    check_condition(!is(rg, "range") | length(rg) != 2,
                     "Wrong class or size for rg object")
     minimum <- rg[1]
     maximum <- rg[2]
@@ -15,4 +15,4 @@ sample_within_range <- function(rg, sample_size = NULL, seed = NULL) {
     if (!is.null(seed)) set.seed(seed)
     out <- sample(sample_space, sample_size, replace = TRUE)
     return(out)
-}
\ No newline at end of file
+}
